from setuptools import setup

setup(name='distributions_mmmk',
      version='0.1',
      description='Gaussian distributions',
      packages=['distributions_mmmk'],
      author = 'Mica Knox',
      zip_safe=False)
